@@ -1,5 +1,5 @@
 #file: scripting.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file controls the datafile scripting, both loading and executing.
@@ -220,7 +220,7 @@ def activate_line(x, y, z, command, tile_type=""):
 					2)[2].strip(), tile_type)
 			else: return_num = "end"
 
-	elif switch == "info":  #display messagebox
+	elif switch == "info":  #display line of text in textbox below main screen
 		has_dialog = 1
 		main.print_message(command.split(None, 1)[1])
 		has_dialog = 0
@@ -229,6 +229,7 @@ def activate_line(x, y, z, command, tile_type=""):
 	elif switch == "is_equipped": #is the given item equipped?
 		match = command.split(None, 1)[1].strip().lower()
 		for item_title in g.item.equip:
+			if item_title == -1: continue
 			if g.item.item[item_title].name.lower() == match:
 				return 1
 		return 0
@@ -287,6 +288,7 @@ def activate_line(x, y, z, command, tile_type=""):
 		else: return_num = 0
 
 	elif switch == "run":  #Run the actions of a different tile.
+		#This may or may not work. I need to check.
 		temp_zgrid = g.mapname2zgrid(command.split()[1])
 		if temp_zgrid == -1:
 			temp_zgrid = g.zgrid
@@ -309,28 +311,32 @@ def activate_line(x, y, z, command, tile_type=""):
 	elif switch == "set":  #set variable (in g.var_list)
 		command2 = command.split(None, 1)[1].strip()
 		if -1 != command2.find("="):
-			g.var_list[command2.split("=", 1)[0].lower().strip()] = \
-				command2.split("=", 1)[1].strip()
+			message = interpret_line(command2.split("=", 1)[1].strip())
+			g.var_list[command2.split("=", 1)[0].lower().strip()] = message
 			return_num = 1
 		elif -1 != command2.find("+"):
 			if 0 == \
 				g.var_list.has_key(command2.split("+", 1)[0].lower().strip()):
 				g.var_list[command2.split("+", 1)[0].lower().strip()] = 0
+			message = interpret_line(command2.split("+", 1)[1].strip())
+			#The reason I don't just use a += command is that g.var_list[x]
+			#may be a string.
 			g.var_list[command2.split("+", 1)[0].lower().strip()] = \
 			int(g.var_list[command2.split("+", 1)[0].lower().strip()]) + \
-			int(command2.split("+", 1)[1].strip())
+			int(message)
 			return_num = 1
 		elif -1 != command2.find("-"):
 			if 0 == \
 				g.var_list.has_key(command2.split("-", 1)[0].lower().strip()):
 				g.var_list[command2.split("-", 1)[0].lower().strip()] = 0
+			message = interpret_line(command2.split("-", 1)[1].strip())
 			g.var_list[command2.split("-", 1)[0].lower().strip()] = \
 			int(g.var_list[command2.split("-", 1)[0].lower().strip()]) - \
-			int(command2.split("-", 1)[1].strip())
+			int(message)
 			return_num = 1
 		else: #no modifier; use =
-			g.var_list[command.split(None, 2)[1].lower()] = \
-				command.split(None, 2)[2]
+			message = interpret_line(command.split(None, 2)[2].strip())
+			g.var_list[command.split(None, 2)[1].lower()] = message
 			return_num = 1
 
 	elif switch == "stat":  #return stat
@@ -365,7 +371,7 @@ def activate_line(x, y, z, command, tile_type=""):
 		has_dialog = 0
 		return_num = 1
 
-	elif switch == "take":  #Take/drop item, by name.
+	elif switch == "take":  #Drop item, by name.
 		temp = g.item.find_inv_item(g.item.finditem(command.split(None, 1)[1]))
 		if temp == -1:
 			return_num = 0
@@ -376,9 +382,12 @@ def activate_line(x, y, z, command, tile_type=""):
 	elif switch == "var":  #return variable (in g.var_list)
 		command2 = command.split(None, 1)[1].lower().strip()
 		if (g.var_list.has_key(command2)):
-			if g.var_list[command2].isdigit():
+			try:
+				if g.var_list[command2].isdigit():
+					return_num = int(g.var_list[command2])
+				else: return_num = g.var_list[command2]
+			except AttributeError:
 				return_num = int(g.var_list[command2])
-			else: return_num = g.var_list[command2]
 		else: return_num = 0
 
 	elif switch == "walk":  #change tile walkability
@@ -395,3 +404,39 @@ def activate_line(x, y, z, command, tile_type=""):
 		print "Bad action of: " + switch + " given."
 		return_num = 0
 	return return_num
+
+
+#given a string such as info or question uses, interpret all ~Action~
+#embedded commands, and return the displayable string.
+def interpret_line(message):
+	#The ~Command~ sequence enables commands to be inserted into info.
+	num_of_tildes = message.count("~")
+	#Check for no ~'s. This should be most common.
+	if num_of_tildes == 0:
+		return message
+
+	#See if the string is formatted correctly.
+	if num_of_tildes % 2 == 1:
+		print "Unmatched ~ character: " + message
+		return "Unmatched ~ character: " + message
+
+	#Interpret the embedded commands:
+	cur_str_pos = -1  #The current pointer into message
+	endstring = ""  #The interpreted string.
+	while cur_str_pos <= len(message):
+		start_tilde = message.find("~", cur_str_pos+1)
+		if start_tilde == -1:
+			endstring += message[cur_str_pos+1:]
+			break
+		endstring += message[cur_str_pos+1:start_tilde]
+		end_tilde = message.find("~", start_tilde+1)
+		if start_tilde+1 == end_tilde: endstring += "~"
+
+		#we now know that message[start_tilde+1:end_tilde] is a command
+		else:
+			line_return = activate_line(g.xgrid, g.ygrid, g.zgrid,
+									message[start_tilde+1:end_tilde])
+			#Add the returned data into the end string.
+			endstring += str(line_return)
+		cur_str_pos = end_tilde
+	return endstring
