@@ -17,7 +17,7 @@ import monster
 
 mon_index = 0
 
-mon_hp = StringVar()
+#mon_hp = StringVar()
 hp = StringVar()
 ep = StringVar()
 
@@ -42,30 +42,35 @@ monster_list = []
 
 #Current monster. Used to display stuff like description.
 #Use with monster_list[cur_monster]
+#Note that this is temporary, used to help the move to multi-monster.
 cur_monster = 0
 
 #Number of times you've tried to run from this monster.
 #Used to allow better chances after a while.
 run_attempts = 0
 
+#x location of the monster hp bar per monster. Used to redraw it.
+base_mon_hp_start = []
+base_mon_hp_width = []
+#y location of the monster hp bar per monster. Used to redraw it.
+base_mon_hp_y_start = []
+
 #refreshes the battle view. Call after changing anything.
 def refresh():
-	mon_hp.set(str(monster_list[cur_monster].hp) + "/" +
-										str(monster_list[cur_monster].maxhp))
-
 	#hp/ep bars
-	canvas_mon_hp.delete("show_mon_hp")
-	canvas_mon_pic.itemconfig(canvas_mon_pic.find_withtag("mon_hp"),
-			text=str(monster_list[cur_monster].hp) + "/" +
-			str(monster_list[cur_monster].maxhp))
+	for i in range(len(monster_list)):
+		canvas_mon_pic.itemconfig(canvas_mon_pic.find_withtag("mon_hp"+str(i)),
+			text=str(monster_list[i].hp) + "/" +
+			str(monster_list[i].maxhp))
 
-#	create_text(170, 168, anchor=NW, text=mon_hp, tags="mon_hp")
-
-	temp_width = g.hpbar_width*int(monster_list[cur_monster].hp) / \
-										int(monster_list[cur_monster].maxhp)
-	if temp_width < 0: temp_width=0
-	canvas_mon_hp.create_rectangle(0, 0, temp_width,
-		g.hpbar_width/6, fill="#05BB05", tags="show_mon_hp")
+		temp_width = base_mon_hp_width[i]*int(monster_list[i].hp) / \
+											int(monster_list[i].maxhp)
+		if temp_width < 0: temp_width=0
+		canvas_mon_pic.coords(canvas_mon_pic.find_withtag("monster_hp_rect"+str(i)),
+				base_mon_hp_start[i],
+				base_mon_hp_y_start[i],
+				base_mon_hp_start[i] + temp_width,
+				base_mon_hp_y_start[i]+5)
 
 	main.recalc_stats(1)
 
@@ -84,75 +89,79 @@ def refresh():
 
 
 #attack button was pressed
+#FIX for multimonster
 def attack(event=0):
 	global cur_button
 	if monster_list[cur_monster].hp > 0 and g.hp > 0:
-		attack_monster()
-	if monster_list[cur_monster].hp > 0 and g.hp > 0:
-		attack_player()
+		attack_monster(cur_monster)
+	for i in range(len(monster_list)):
+		if monster_list[i].hp > 0 and g.hp > 0:
+			attack_player(i)
+	if monster_list[cur_monster].hp > 0:
 		refresh()
 		refresh_buttons()
 
-#attack the monster
-def attack_monster():
+#attack the i'th monster in monster_list[].
+def attack_monster(i):
 	global cur_mon_hp
 	#find the damage done
 	damage = g.die_roll(1, g.adj_attack + 2)
-	damage = damage - g.die_roll(1, monster_list[cur_monster].defense + 2)
+	damage = damage - g.die_roll(1, monster_list[i].defense + 2)
 	if damage > 0:
- 		main.print_message("You hit the " + monster_list[cur_monster].name +
+ 		main.print_message("You hit the " + monster_list[i].name +
  			" for " + str(damage) + " damage.")
-		monster_list[cur_monster].hp = monster_list[cur_monster].hp - damage
+		monster_list[i].hp = monster_list[i].hp - damage
 		#you kill it?
-		if monster_list[cur_monster].hp <= 0:
-			monster_dead()
+		if monster_list[i].hp <= 0:
+			monster_dead(i)
 			return 0
 	else:
 		main.print_message("You miss the " +
-				monster_list[cur_monster].name + ".")
+				monster_list[i].name + ".")
 
 
 #monster attacks you
-def attack_player():
-	damage = g.die_roll(1, monster_list[cur_monster].attack + 2)
+def attack_player(i):
+	damage = g.die_roll(1, monster_list[i].attack + 2)
 	damage = damage - g.die_roll(1, g.adj_defense + 2)
 	if damage > 0:
-		main.print_message("The " + monster_list[cur_monster].name +
+		main.print_message("The " + monster_list[i].name +
 		" hits you for " + str(damage) + " damage.")
 		g.hp = g.hp - damage
 		#you dead yet?
 		if g.hp <= 0:
-			main.print_message("The " + monster_list[cur_monster].name +
+			g.hp = 0
+			main.print_message("The " + monster_list[i].name +
 			" kills you.")
 			cur_button = 1
 
-	elif monster_list[cur_monster].hp > 0:
-		main.print_message("The " + monster_list[cur_monster].name +
+	elif monster_list[i].hp > 0:
+		main.print_message("The " + monster_list[i].name +
 		" misses you.")
-	refresh()
+
 
 #use to reward the player for killing a monster
-def monster_dead():
+#FIX for multimonster
+def monster_dead(i):
 	#make the display look better
-	monster_list[cur_monster].hp = 0
+	monster_list[i].hp = 0
 	#add info to listbox_move; add gold and xp
-	main.print_message("The " + monster_list[cur_monster].name +
+	main.print_message("The " + monster_list[i].name +
 	" dies.")
 
-
-	if len(monster_list[cur_monster].on_death) == 0:
-		gold = monster_list[cur_monster].gold
+	if len(monster_list[i].on_death) == 0:
+		gold = monster_list[i].gold
 		g.gold = str(int(g.gold) + gold)
 		main.print_message("You find " + str(gold) + " gold,")
 
-		exp = monster_list[cur_monster].exp
+		exp = monster_list[i].exp
 		main.print_message("and get " + str(exp) + " experience.")
 		g.add_exp(exp)
 	else:
 		i=0
-		while i < len(monster_list[cur_monster].on_death):
+		while i < len(monster_list[i].on_death):
 			temp = action.activate_line(g.xgrid, g.ygrid, g.zgrid,
-				monster_list[cur_monster].on_death[i])
+				monster_list[i].on_death[i])
 			if temp == "end": break
 			if main.dead_yet() == 1:
 				break
@@ -165,6 +174,7 @@ def monster_dead():
 	did_run = 0
 
 #run/leave/quit button was pressed
+#FIX for multimonster
 def runaway():
 	global run_attempts
 	try:
@@ -183,13 +193,14 @@ def runaway():
 			else:
 				run_attempts += 1
 				main.print_message("You fail to run away.")
-				attack_player()
+				attack_player(cur_monster)
 	except TclError:
 		pass
 
 #Use item button was pressed
 def useitem():
 	#don't do anything if anyone is dead.
+#FIX for multimonster
 	if monster_list[cur_monster].hp < 1 or g.hp < 1:
 		return 0
 
@@ -215,9 +226,11 @@ def useitem():
 					str(g.item.item[item_value].quality) + " health.")
 		g.item.drop_inv_item(g.item.find_inv_item(item_value))
 		if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
-		attack_player()
+#FIX for multimonster
+		attack_player(cur_monster)
 
 	#if item is explosive
+#FIX for multimonster
 	if item_type == 12:
 		#if monster is still alive
 		if monster_list[cur_monster].hp > 0:
@@ -229,10 +242,10 @@ def useitem():
 			monster_list[cur_monster].hp = monster_list[cur_monster].hp - damage
 			#you kill it?
 			if monster_list[cur_monster].hp <= 0:
-				monster_dead()
+				monster_dead(cur_monster)
 				return 0
 			else:
-				attack_player()
+				attack_player(cur_monster)
 	refresh()
 
 	#replace the cursor
@@ -245,6 +258,8 @@ def useitem():
 	refresh_buttons()
 
 
+#Use a skill. Called upon hitting the right button; uses the listbox position.
+#FIX for multimonster
 def useskill():
 	#don't do anything if monster is dead.
 	if monster_list[cur_monster].hp < 1 or g.hp < 1:
@@ -276,7 +291,7 @@ def useskill():
 		#increase attack ability
 		g.adj_attack += (1 + int(g.level)/4)
 		main.attack.set(g.adj_attack)
-		attack_player()
+		attack_player(cur_monster)
 
 	elif g.skill[skill_index][1] == 1: #Sneak away
 		global run_attempts
@@ -290,15 +305,15 @@ def useskill():
 		else:
 			run_attempts += 3
 			main.print_message("You fail to sneak away.")
-			attack_player()
+			attack_player(cur_monster)
 	elif g.skill[skill_index][1] == 2: #Frenzy
 		for i in range(2 + int(g.level)/3):
-			attack_monster()
+			attack_monster(cur_monster)
 			if monster_list[cur_monster].hp <= 0:
 #				monster_dead()
 				return 0
 		if monster_list[cur_monster].hp > 0:
-			attack_player()
+			attack_player(cur_monster)
 	elif g.skill[skill_index][1] == 3: #Dismember
 		damage = g.adj_attack * 2
 		main.print_message("You hit the " + monster_list[cur_monster].name +
@@ -306,10 +321,10 @@ def useskill():
 		monster_list[cur_monster].hp = monster_list[cur_monster].hp - damage
 		#you kill it?
 		if monster_list[cur_monster].hp <= 0:
-			monster_dead()
+			monster_dead(cur_monster)
 			return 0
 		else:
-			attack_player()
+			attack_player(cur_monster)
 
 	refresh()
 
@@ -330,6 +345,7 @@ def refresh_buttons():
 	if (cur_button == 0):
 		canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=attack_button_sel)
+#FIX for multimonster
 		help_text.set("Attack the " + monster_list[cur_monster].name)
 	else: canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=attack_button)
@@ -633,7 +649,8 @@ def begin(mon_index_input):
 	global monster_list
 	monster_list = []
 	for line in monster.monster_groups[mon_index].monster_list:
-		monster_list.append(monster.monsters[monster.monster_name_to_index(line)])
+		monster_list.append(monster.copy_monster(
+				monster.monsters[monster.monster_name_to_index(line)]))
 	for i in range(len(monster_list)):
 		monster_list[i].reset()
 
@@ -674,41 +691,63 @@ def begin(mon_index_input):
 
 	global canvas_mon_pic
 	background_pic = g.maps[g.zgrid].battle_background
-	if os.path.isfile(g.mod_directory +
-			"/images/tiles/monsters/" + monster_list[cur_monster].name + ".png"):
-		monster_pic = ImageTk.PhotoImage(file=g.mod_directory +
-			"/images/tiles/monsters/" + monster_list[cur_monster].name + ".png")
-	else:
-		monster_pic = ImageTk.PhotoImage(file=g.mod_directory +
-			"/images/tiles/monsters/generic.png")
 	canvas_mon_pic = Canvas(pic_frame,
 		height=background_pic.height(),
 		width=background_pic.width())
 	canvas_mon_pic.grid(column=2, row=1, rowspan=5, sticky=NW)
 	canvas_mon_pic.create_image(0, 0, anchor=NW, image=background_pic)
-	canvas_mon_pic.create_image(background_pic.width()/2, 10, anchor=N, image=monster_pic)
+	monster_pic = []
+	global base_mon_hp_start
+	global base_mon_hp_width
+	global base_mon_hp_y_start
+	for i in range(len(monster_list)):
+		if os.path.isfile(g.mod_directory +
+				"/images/tiles/monsters/" + monster_list[i].name + ".png"):
+			monster_pic.append(ImageTk.PhotoImage(file=g.mod_directory +
+				"/images/tiles/monsters/" + monster_list[i].name + ".png"))
+		else:
+			monster_pic.append(ImageTk.PhotoImage(file=g.mod_directory +
+				"/images/tiles/monsters/generic.png"))
+#FIX
+		canvas_mon_pic.create_image(background_pic.width()/2+i*40, 10,
+			anchor=N, image=monster_pic[i])
 
+		base_mon_hp_start.append(background_pic.width()/2 - monster_pic[i].width()/2+i*40)
+		base_mon_hp_width.append(monster_pic[i].width())
+		base_mon_hp_y_start.append(15+monster_pic[i].height())
+		#Under (red) part of the monster hp display
+		canvas_mon_pic.create_rectangle(base_mon_hp_start[i], base_mon_hp_y_start[i],
+				base_mon_hp_start[i]+base_mon_hp_width[i],
+				base_mon_hp_y_start[i]+5, fill="#EE0505")
+		#Over (green) part of the monster hp display
+		canvas_mon_pic.create_rectangle(base_mon_hp_start[i], base_mon_hp_y_start[i],
+				base_mon_hp_start[i]+base_mon_hp_width[i],
+				base_mon_hp_y_start[i]+5, fill="#05BB05",
+				tags="monster_hp_rect"+ str(i))
+		canvas_mon_pic.create_text(background_pic.width()/2+i*40,
+			base_mon_hp_y_start[i]+7, anchor=N, text="", tags="mon_hp"+str(i))
 
-	global canvas_mon_hp
-	canvas_mon_hp = Canvas(pic_frame, width=g.hpbar_width,
-		height=g.hpbar_width/6, highlightthickness=0)
-	canvas_mon_hp.grid(column=2, row=5)
-	canvas_mon_hp.create_rectangle(0, 0, g.hpbar_width,
-		g.hpbar_width/6, fill="#EE0505")
+	if os.path.isfile(g.mod_directory + "/images/tiles/people/hero_n.png"):
+		hero_pic = ImageTk.PhotoImage(file=g.mod_directory +
+					"/images/tiles/people/hero_n.png")
+		canvas_mon_pic.create_image(
+				background_pic.width()/2,
+				background_pic.height()-hero_pic.height()-5,
+				anchor=N, image=hero_pic)
 
 
+#FIX for multimonster
 	#formatting for the labels.
 	label_formatting = Label(window_battle,
 			text=monster_list[cur_monster].name, bg=bgcolour).grid(row=1,
 			column=1, columnspan=2)
 
-	canvas_mon_pic.create_text(25, 168, anchor=NW, text="HP:")
-	canvas_mon_pic.create_text(152, 168, anchor=NW, text=mon_hp, tags="mon_hp")
 
 	#stat display
 #	label_mon_hp = Label(pic_frame, textvariable=mon_hp,
 #		bg="#327a22").grid(row=5, column=2, sticky=E, padx=2)
 
+#FIX for multimonster
 	label_attack = Label(window_battle, text="Attack: " +
 	str(monster_list[cur_monster].attack), bg=bgcolour).grid(row=4,
 			column=1, sticky=W)
