@@ -5,7 +5,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.40. Released under the GPL. Copyright 2005
+#Dragon Hunt 3.41. Released under the GPL. Copyright 2005
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -373,17 +373,8 @@ def read_perturn():
 	global per_turn_script
 	for i in range(30):
 		per_turn_script.append([])
-	file = open(mod_directory + "/data/perturn.txt", 'r')
-	line = file.readline()
-	while (line != ''):
-		line = line.strip()
-		if (line[:1] == "#" or line[:1] == ""):
-			line = file.readline()
-			continue
-		#allow the \ line-continuation character.
-		while line[-1:] == "\\":  #really a single backslash, BTW.
-			line = line[:-1] + file.readline()[:-1]
-
+	per_turn_lines = read_script_file("/data/perturn.txt")
+	for line in per_turn_lines:
 		line = line.strip()
 		if line[:1] == ":": #start defining more tiles.
 			cur_turns = []
@@ -396,10 +387,6 @@ def read_perturn():
 		else:
 			for turn_num in cur_turns:
 				per_turn_script[turn_num].append(line)
-		#ready another line
-		line = file.readline()
-	file.close()
-
 
 
 #skills array. Each skill is a separate line in the array. Each line goes:
@@ -558,3 +545,34 @@ def load_backgrounds():
 				else: #if image is in root dir
 					backgrounds[tilename] = \
 						ImageTk.PhotoImage(file=root + "/" + tilename)
+
+
+#given a filename, return the script contained in the file.
+#Deals with comments, empty lines, and line-continuation.
+def read_script_file(file_name):
+	temp_array = []
+	file = open(g.mod_directory + file_name, 'r')
+
+	#go through all lines of the file
+	file_line = file.readline()
+	while file_line != '':
+		#strip out spaces/tabs
+		file_line = file_line.strip()
+
+		#ignore blank lines and comments
+		if file_line[:1] == "#" or file_line[:1] == "":
+			file_line = file.readline()
+			continue
+
+		#allow the \ line-continuation character.
+		while file_line[-1:] == "\\":  #really a single backslash, BTW.
+			file_line = file_line[:-1] + file.readline()[:-1]
+
+		temp_array.append(file_line)
+
+		#ready another line
+		file_line = file.readline()
+
+	file.close()
+	return temp_array
+
