@@ -1,5 +1,5 @@
 #file: main.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file controls the wilderness and dungeon.
@@ -65,11 +65,12 @@ level = StringVar()
 
 
 
-#print a message in status box
+#Print a message in status box. Works with ~Action~ embedded commands.
 def print_message(message):
 	try:
 		if window_main.state() != "normal":
 			return 0
+		message = action.interpret_line(message)
 		listbox_status.insert(END, message)
 		listbox_status.see(END)
 
@@ -404,6 +405,7 @@ def start_battle(mon_index):
 #Call to display a dialog box. Used to work with action.py.
 #Note this only works if window_main is visible.
 def show_dialog(line=None):
+	line = action.interpret_line(line)
 	if window_main.state() != "normal":
 		return 0
 
@@ -422,7 +424,7 @@ def show_dialog(line=None):
 		x2 = (mapsizex*tilesize/2) + yes_button.width()
 	#background
 	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+no_button.height(),
-		fill="#5050ff", outline="Black", tags="background_box")
+		fill=g.fill_colour, outline="Black", tags="background_box")
 	canvas_map.lift("dialogtxt")
 	#button
 	canvas_map.create_image((mapsizex*tilesize/2),
@@ -444,6 +446,7 @@ def show_dialog(line=None):
 
 #given a string, display that string, along with yes and no buttons.
 def show_yesno(line=""):
+	line = action.interpret_line(line)
 	if window_main.state() != "normal":
 		return 0
 	action.has_dialog = 1
@@ -463,7 +466,7 @@ def show_yesno(line=""):
 		x2 = (mapsizex*tilesize/2) + yes_button.width()
 	#background
 	canvas_map.create_rectangle(x1-5, y1-5, x2+5, y2+no_button.height(),
-		fill="#5050ff", outline="Black", tags="background_box")
+		fill=g.fill_colour, outline="Black", tags="background_box")
 	canvas_map.lift("dialogtxt")
 	#buttons
 	canvas_map.create_image((mapsizex*tilesize/2),
