@@ -141,13 +141,14 @@ def move_right(event=None):
 	refresh_map()
 
 def map_callback(event):
-	if(cur_tile != "" or cur_mode == "remove"):
+	if(cur_tile != "" or cur_mode == "remove" or cur_mode == "walkable"):
 		set_tile((event.x / g.tilesize)+portal_x, (event.y / g.tilesize)+portal_y, cur_tile)
 
-#set mode to add, replace, or remove
+#set mode to add, replace, remove, or walkable
 def set_mode(mode):
-    global cur_mode
-    cur_mode = mode
+	global cur_mode
+	cur_mode = mode
+	refresh_map()
 
 #set all interior tiles to background tile
 def set_bkg(bkg):
@@ -197,7 +198,29 @@ def refresh_map():
 					canvas_map.create_image((x-portal_x)*g.tilesize,
 						(y-portal_y)*g.tilesize, anchor=NW,
 						image=g.tiles[line.strip().split()[7].strip()])
+	#if we are adjusting walkable status, display black/white box on tile
+	if cur_mode == "walkable":
+		for y in range(portal_y, portal_y+portalsize):
+			if y >= mapsize_y: return
+			for x in range(portal_x, portal_x+portalsize):
+				if x >= mapsize_x: break
+				for line in cur_map.field[y][x].onload:
+					if line.strip().lower() == "walk 1":
+						canvas_map.create_rectangle(
+							(x-portal_x)*g.tilesize + g.tilesize/3,
+							(y-portal_y)*g.tilesize + g.tilesize/3,
+							(x-portal_x)*g.tilesize + 2*g.tilesize/3,
+							(y-portal_y)*g.tilesize + 2*g.tilesize/3,
+							fill="white")
+					if line.strip().lower() == "walk 0":
+						canvas_map.create_rectangle(
+							(x-portal_x)*g.tilesize + g.tilesize/3,
+							(y-portal_y)*g.tilesize + g.tilesize/3,
+							(x-portal_x)*g.tilesize + 2*g.tilesize/3,
+							(y-portal_y)*g.tilesize + 2*g.tilesize/3,
+							fill="black")
 	scroll_from_map()
+	#g.tilesize/3
 
 #set tile at x, y to name.
 def set_tile(x, y, name):
@@ -209,11 +232,17 @@ def set_tile(x, y, name):
 	if tile_prefix == "items":
 		add_item(x, y, name)
 	elif cur_mode == "add":
-	    	cur_map.field[y][x].onload.append("addpix " + name);
+		cur_map.field[y][x].onload.append("addpix " + name);
 	elif cur_mode == "remove":
-	   	cur_map.field[y][x].onload = []
+		cur_map.field[y][x].onload = []
 		cur_map.field[y][x].onload.append("pix " + background)
-                cur_map.field[y][x].onload.append("walk 1")
+		cur_map.field[y][x].onload.append("walk 1")
+	elif cur_mode == "walkable":
+		for line_num in range(len(cur_map.field[y][x].onload)):
+			if cur_map.field[y][x].onload[line_num] == "walk 1":
+				cur_map.field[y][x].onload[line_num] = "walk 0"
+			elif cur_map.field[y][x].onload[line_num] == "walk 0":
+				cur_map.field[y][x].onload[line_num] = "walk 1"
 	else:
 		temp_name = name
 		for line_num in range(len(cur_map.field[y][x].onload)):
@@ -709,6 +738,7 @@ def make_menus():
 	mapmode_menu.add_command(label='Replace Tile (default)', command=(lambda x="replace":set_mode(x)))
 	mapmode_menu.add_command(label='Add Tile (transparency)', command=(lambda x="add":set_mode(x)))
 	mapmode_menu.add_command(label='Reset Tile (clear to background)', command=(lambda x="remove":set_mode(x)))
+	mapmode_menu.add_command(label='Adjust walkable staus', command=(lambda x="walkable":set_mode(x)))
 
 	#mapsize submenu
 	mapsize_menu = Menu(map_options, bg=bgcolour)
