@@ -1,15 +1,21 @@
 #file: shop.py
-#Copyright (C) 2004 Free Software Foundation
+#Copyright (C) 2005 Free Software Foundation
 #see GPL.txt for license.
 
 #This file controls the town shops.
 
 
 from Tkinter import *
+#needed for the buttons.
+import ImageTk
+import Image
+
 import main
 import g
 import item
 
+
+
 #location of the store in the g.shops[] array
 global store_num
 store_num = 0
@@ -24,6 +30,13 @@ curr_item = 0
 #If inv (0) or shop (1) has focus.
 curr_focus = 1
 
+#currently selected button: 0=sell 1=leave 2=buy
+cur_button=2
+
+leave_height=0
+buy_height=0
+sell_height=0
+
 #array containing the item[] index of all inventory items.
 #Used to determine which item to sell/drop
 #global listbox_inv_array
@@ -37,6 +50,24 @@ item_desc  = StringVar()
 curr_gold  = StringVar()
 curr_skill = StringVar()
 
+#refresh the button canvas
+def refresh_buttons(event=0):
+	canvas_buttons.delete(ALL)
+	if (cur_button == 0):
+	    canvas_buttons.create_image(0, 0, anchor=NW, image=sell_button_sel)
+	else:
+	    canvas_buttons.create_image(sell_height, 0, anchor=NW, image=sell_button)
+
+	if (cur_button == 1):
+	    canvas_buttons.create_image(leave_height, 0, anchor=NW, image=leave_button_sel)
+	else:
+	    canvas_buttons.create_image(leave_height, 0, anchor=NW, image=leave_button)
+
+	if (cur_button == 2):
+	    canvas_buttons.create_image(buy_height, 0, anchor=NW, image=buy_button_sel)
+	else:
+    	    canvas_buttons.create_image(buy_height, 0, anchor=NW, image=buy_button)
+
 
 #refresh the inventory canvas
 def refresh_inv():
@@ -51,7 +82,7 @@ def refresh_inv():
 							2 * ((curr_item/shop_width)+1),
 				((curr_item%shop_width)+1)*(g.tilesize + 2),
 				((curr_item/shop_width)+1)*(g.tilesize + 2),
-							fill="#A0A0ff", tags="item")
+							fill=g.fill_sel_colour, tags="item")
 
 	#draw the item pictures.
 	for i in range(len(item.inv)):
@@ -114,7 +145,7 @@ def refresh_shop():
 												((curr_item/shop_width)+1),
 				((curr_item%shop_width)+1)*(g.tilesize + 2),
 				((curr_item/shop_width)+1)*(g.tilesize + 2),
-												fill="#A0A0ff", tags="item")
+												fill=g.fill_sel_colour, tags="item")
 
 	#draw the item pictures.
 	for i in range(len(g.shops[store_num].itemlist)):
@@ -255,29 +286,52 @@ def leave_shop(event=0):
 	except TclError:
 		pass
 
+def mouse_handler_click(event=0):
+	key_handler("return")
+
+def mouse_handler_move(event=0):
+        global cur_button
+        if (event.x < leave_height):
+                cur_button = 0
+        elif (event.x < buy_height):
+                cur_button = 1
+        else: cur_button = 2
+        refresh_buttons()
 
 #All keypresses in window_shop pass through here. Based on the key name,
 #give the right action. ("etc", "left", "right", "up", "down", "return")
 def key_handler(switch):
 	global curr_item
+	global cur_button
 	global curr_focus
 	#switch based on keycode
 	if (switch == "esc"):
 		leave_shop()
 		return
 	elif (switch == "return"):
-		if curr_focus == 1: buy_item()
-		else: sell_item()
+		if(curr_focus == 1 and cur_button == 2): buy_item()
+		elif(curr_focus !=1 and cur_button == 0): sell_item()
+		elif(cur_button == 1):
+		    leave_shop()
+		    return
 	elif (switch == "left"):
 		if (curr_item % shop_width == 0):  #move between lists
-			if curr_focus == 0: curr_focus = 1
-			else: curr_focus = 0
+			if curr_focus == 0:
+				curr_focus = 1
+				cur_button = 2
+			else:
+				curr_focus = 0
+				cur_button = 0
 			curr_item += shop_width
 		curr_item -= 1
 	elif (switch == "right"):
 		if (curr_item % shop_width == shop_width - 1):  #move between lists
-			if curr_focus == 0: curr_focus = 1
-			else: curr_focus = 0
+			if curr_focus == 0:
+				curr_focus = 1
+				cur_button = 2
+			else:
+				curr_focus = 0
+				cur_button = 0
 			curr_item -= shop_width
 		curr_item += 1
 	elif (switch == "up"):
@@ -291,9 +345,12 @@ def key_handler(switch):
 
 	refresh_inv()
 	refresh_shop()
+	refresh_buttons()
 	show_details()
 
 #Python does not appear to allow arguments in callbacks. Grumble.
+# Yes, I think it does.  take a look at the use of lambda in the
+# map editor.
 def key_handler_esc(event=0): key_handler("esc")
 def key_handler_left(event=0): key_handler("left")
 def key_handler_right(event=0): key_handler("right")
@@ -325,7 +382,7 @@ def init_window_shop(store_type_input):
 	temp_canvas_height=(g.tilesize*shop_height)+ ((shop_height+1)*2) + 1
 	global canvas_inv
 	canvas_inv = Canvas(window_shop, width=temp_canvas_width,
-		height=temp_canvas_height, highlightthickness=0, bg="#202090")
+		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
 	canvas_inv.grid(column=1, row=3, columnspan=2, rowspan=16)
 	#outside border
 	canvas_inv.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
@@ -335,12 +392,12 @@ def init_window_shop(store_type_input):
 			canvas_inv.create_rectangle(x*g.tilesize + 2 * (x+1),
 										y*g.tilesize + 2 * (y+1),
 										(x+1)*(g.tilesize + 2),
-										(y+1)*(g.tilesize + 2), fill="#5050ff")
+										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
 
 	#Shop canvas
 	global canvas_shop
 	canvas_shop = Canvas(window_shop, width=temp_canvas_width,
-		height=temp_canvas_height, highlightthickness=0, bg="#202090")
+		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
 	canvas_shop.grid(column=6, row=3, columnspan=2, rowspan=16)
 	#outside border
 	canvas_shop.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
@@ -350,7 +407,7 @@ def init_window_shop(store_type_input):
 			canvas_shop.create_rectangle(x*g.tilesize + 2 * (x+1),
 										y*g.tilesize + 2 * (y+1),
 										(x+1)*(g.tilesize + 2),
-										(y+1)*(g.tilesize + 2), fill="#5050ff")
+										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
 
 	#Info labels
 	label_name = Label(window_shop, textvar=item_name,
@@ -372,20 +429,48 @@ def init_window_shop(store_type_input):
 
 
 	#Buttons
-	global button_sell
-	button_sell = Button(window_shop, text="Sell", command=sell_item,
-		bg=bgcolour)
-	button_sell.grid(row=28, column=1)
-	global button_buy
-	button_buy  = Button(window_shop, text="Buy",  command=buy_item,
-		bg=bgcolour)
-	button_buy.grid(row=28, column=6)
-	button_leave= Button(window_shop, text="Leave",
-		command=leave_shop, bg=bgcolour).grid(row=28, column=3)
+	global sell_button; global sell_button_sel
+	global buy_button; global buy_button_sel
+	global leave_button; global leave_button_sel
+
+
+	sell_button =  ImageTk.PhotoImage(file=g.mod_directory + \
+	                "/images/buttons/sell.png")
+	sell_button_sel =  ImageTk.PhotoImage(file=g.mod_directory + \
+	                "/images/buttons/sell_sel.png")
+	buy_button =  ImageTk.PhotoImage(file=g.mod_directory + \
+	                "/images/buttons/buy.png")
+	buy_button_sel =  ImageTk.PhotoImage(file=g.mod_directory + \
+	                "/images/buttons/buy_sel.png")
+	leave_button =  ImageTk.PhotoImage(file=g.mod_directory + \
+	                "/images/buttons/leave_shop.png")
+	leave_button_sel =  ImageTk.PhotoImage(file=g.mod_directory + \
+	                "/images/buttons/leave_shop_sel.png")
+
+	global leave_height; leave_height = sell_button.width()
+	global buy_height; buy_height = leave_height + leave_button.width()
+
+	global canvas_buttons
+	canvas_buttons = Canvas(window_shop, height=buy_button_sel.height(),
+		width=buy_height+buy_button.width(), bg=bgcolour)
+	canvas_buttons.grid(column=1, row=29, columnspan=8)
+
+
+#	global button_sell
+#	button_sell = Button(window_shop, text="Sell", command=sell_item,
+#		bg=bgcolour)
+#	button_sell.grid(row=28, column=1)
+#	global button_buy
+#	button_buy  = Button(window_shop, text="Buy",  command=buy_item,
+#		bg=bgcolour)
+#	button_buy.grid(row=28, column=6)
+#	button_leave= Button(window_shop, text="Leave",
+#		command=leave_shop, bg=bgcolour).grid(row=28, column=3)
 
 	#get data in listboxes
 	refresh_inv()
 	refresh_shop()
+	refresh_buttons()
 
 	#bindings
 	canvas_shop.bind("<ButtonRelease-1>", mouse_sel_shop)
@@ -399,6 +484,8 @@ def init_window_shop(store_type_input):
 	main.window_main.bind(g.binding_inv, key_handler)
 	main.window_main.bind(g.binding_save, key_handler)
 	main.window_main.bind(g.binding_quit, key_handler)
+	canvas_buttons.bind("<ButtonRelease-1>", mouse_handler_click)
+        canvas_buttons.bind("<Motion>", mouse_handler_move)
 
 	show_details()
 	window_shop.master.wait_window(window_shop)
